@@ -64,7 +64,7 @@ static void ssh_status_init (SSHStatus *plugin)
             HILDON_BUTTON_STYLE_PICKER);
     hildon_button_set_image (HILDON_BUTTON(b), image);
 
-    WEXITSTATUS(system("sudo /usr/sbin/ssh-status.sh stop"));
+    /* WEXITSTATUS(system("sudo /usr/sbin/ssh-status.sh stop")); */
     int status = WEXITSTATUS(system("sudo /usr/sbin/ssh-status.sh check"));
 
     if (status == 0)
