@@ -1,6 +1,8 @@
 #!/bin/sh
 # 
-# SSH status / switcher modified by Andrei Emeltchenko based upon:
+# SSH status / switcher modified by 
+# Andrei Emeltchenko (2010) and 
+# Serhiy Zahoriya (2013), based upon:
 # Wifi switcher for N900  Copyright (C) 2010 by Tito Ragusa 
 # <farmatito@tiscali.it>
 #
@@ -18,7 +20,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-# Please read the COPYING and README file!!!
+# Please read the COPYING and README file.
 
 debug=1
 
@@ -42,7 +44,7 @@ print_failed_and_die()
 }
 
 if [ "$1" = "check" ] ; then
-	if [ `status sshd | grep -c running` -gt "0" ] ; then
+	if [ `pidof sshd` -gt "0" ] ; then
 	# SSH running
 		exit 0
 	else
@@ -51,24 +53,12 @@ if [ "$1" = "check" ] ; then
 
 else
 
-# Stop SSH service
-if [ "$1" = "stop" ] ; then
-	action="disable"
-	stop sshd
-	if [ $? -ne "0" ] ; then
-		step=": stop failed"
-		print_failed_and_die
-	fi
-	
-	exit 0
-fi
-
 # Toggle SSH server status
-if [ `status sshd | grep -c running` -gt "0" ] ; then
+if [ `pidof sshd` -gt "0" ] ; then
 	# SSH running, stop it
 	action="disable"
 	stop sshd
-	if [ $? -ne "0" ] ; then
+	if [ `pidof sshd` -gt "0" ] ; then
 		step=": stop failed"
 		print_failed_and_die
 	fi
@@ -79,15 +69,12 @@ if [ `status sshd | grep -c running` -gt "0" ] ; then
 else
 	# SSH stopped, run it
 	action="enable"
-	start sshd
-	if [ $? -ne "0" ] ; then
-		step=": start failed"
-		print_failed_and_die
+	step=":$(start sshd 2>&1 >/dev/null)"
+	if [ `pidof sshd` -gt "0" ] ; then
+		print_msg "SSH started" "OK"
+		exit 0
 	fi
-
-	print_msg "SSH started" "OK"
-	
-	exit 0
+	print_failed_and_die
 fi
 
 fi
